import styled from 'styled-components'
import { Link } from 'react-router-dom'
import { Box } from '@material-ui/core'
import background from '../../assets/images/capa.png'

import { fontstyles } from '../../theme/commonstyles'

export const StyledContainer = styled(Box)`
  * {
    padding: 0;
    margin: 0;
  }

  max-width: 100vw;
  max-height: 100vh;
  display: flex;  
  flex-direction: column;
  overflow: hidden;  

  background: linear-gradient(93deg, rgba(29,59,117,1) 0%, rgba(30,104,134,1) 100%);
  background: url(${background}) no-repeat;
  background-size: auto 100%;

  @media(min-width: 900px) {
    background-size: 100% 100%;
  }

  @keyframes slide {
    from {
      transform: translateX(-80px);
      opacity: 0;
    }

    to {
      transform: translateX(0);
      opacity: 1;
    }
  }

  ${fontstyles};

  #container{
    flex-grow: 1; 
    display: flex;
    align-items: center;
    justify-content: center;
    min-height: calc(80vh);
    max-height: calc(80vh);
    max-width: 1800px;
    margin: auto;

    @media(min-width: 1000px) {
      min-height: 75vh;
      max-height: 75vh;
    }
  }

  #texts{
    display: flex;
    justify-content: center;
    align-items: center;
    padding: 10px;

    @media(min-width: 1000px) {
      padding: 0;
    }
  }

  #texts .wrapper {
    width: 100%;
    display: flex;
    flex-direction: column;
    align-items: center;
    justify-content: center;
    
    @media(min-width: 1000px) {
      width: 80%;
      margin: auto;
    }
  }

  #button{
    flex-grow: 1;
    display: flex;
    align-items: center;
    justify-content: center;

    @media(min-width: 1000px){
      /* justify-content: flex-end;
      margin-right: 13vw; */
    }
  }

  #title, #text {
    color: ${props => props.theme.palette.background.main};
    text-shadow: 0px 3px 2px rgba(0, 0, 0, 0.5);    
  }

  #title {
    margin-bottom: 1rem;
    margin: 2rem 0;    
    text-align: center;    
  }

  h3 {
    font-weight: bolder;
    font-family: opensans;

    @media(min-width: 900px){
      font-size: 3.5vw;
    }
  }
`

export const Iniciar = styled(Link)`
  background-color: ${props => props.theme.palette.button.iniciar};
  box-shadow: 4px 10px 28px rgba(0,0,0,0.25), 4px 6px 10px rgba(0,0,0,0.22);
  border-radius: 200px;
  width: 14rem;
  height: 3.5rem;
  margin: 20px 0;
  display: flex;
  align-items: center;
  justify-content: center;
  overflow: hidden;
  transition: all 0.3s cubic-bezier(.25,.8,.25,1);
  animation: slide backwards;
  animation-duration: 500ms;
  animation-delay: 400ms;

  @media(min-width: 900px){  
    width: 32vh;
    height: 8.5vh;
  }

  &:hover {
    background-color: ${props => props.theme.palette.button.dark};
    transition: all 0.3s cubic-bezier(.25,.8,.25,1);
    box-shadow: 4px 19px 38px rgba(0,0,0,0.30), 4px 15px 12px rgba(0,0,0,0.22);
    transform: scale(1.1);
  }

  img{
    width: 100%;
  }
`