import React, { useState, useRef } from "react"
import { Typography, Box } from "@material-ui/core"

import Header from "../../components/Header"
import Footer from "../../components/Footer"
import Reference from "../../components/Reference"

import { Content, StyledContainer } from "./styles"
import { SelectButton } from '../../theme/commonstyles'

export default function () {
  const headerref = useRef(Header)
  const [selected, setSelected] = useState(0)

  const openRef = (key) => {
    if (!headerref.current) {
      return
    }

    headerref.current.openRef(key)
  }

  const CENDES = () => {
    return (
      <Typography variant="body1">
        • Surge em 1965, publicado pela Organização Pan-Americana de Saúde (OPAS);
        <br />
        • A realidade funciona como norma;
        <br />
        • Visa otimizar os ganhos econômicos ou diminuir os custos;
        <br />
        • As decisões são tomadas pelo custo-benefício;
        <br />
        • O planejador, externo ao contexto, baseado em seus conhecimentos técnicos "neutros", faz o plano e estabelece prioridades;
        <br />
        • Um ator planeja com plenos poderes;
        <br />
        • Ignora a dimensão política do planejamento;
        <br />
        • Não assume a variabilidade da realidade, a existência de conflitos e de diversos interesses;
        <br />
        • Caiu em descrédito ao não dar conta da complexidade da realidade.        
      </Typography>
    )
  }

  const ENFOQUE = () => {
    return (
      <Typography variant="body1">
        • Referência: Carlos Matus, década de 1970;
        <br />
        • Incorpora a dimensão política;
        <br />
        • A trajetória é flexível, sujeita a revisões de acordo com as circunstâncias;
        <br />
        • Baseia-se na visão dos sujeitos que vivem a realidade sobre a qual se vai intervir (atores sociais);
        <br />
        • A busca da modificação do sistema baseia-se no conhecimento da realidade e não em uma imposição sobre a realidade;
        <br />
        • Conflito como característica do processo de planejamento que será mediado e dosado, mas nunca negado.
      </Typography>
    )
  }

  const texts = [<CENDES />, <ENFOQUE />]

  return (
    <StyledContainer>
      <Header ref={headerref} />
      <Box className="container">
        <Content>
          <Box className="title">
            <Typography variant="h3">
              O processo de planejamento
            </Typography>
          </Box>
          <Box className="wrapper">
            <Box className="text">
              <Typography variant="body1" className="indented">
                Existe uma vasta bibliografia sobre planejamento na literatura
                internacional, especialmente na América Latina, que se inicia na
                economia, mas depois se passa às áreas sociais. A planificação de
                sistemas de saúde foi objeto de muitos estudos e produções que
                tratam sobre possibilidades de condução do processo de
                planejamento. <strong>Clique</strong> nos botões abaixo para conhecer brevemente
                algumas das abordagens.<Reference num={2} onClick={() => openRef(2)} />
              </Typography>
            </Box>
            <Box className="bottom">
              <Box className="buttons">
                {/* "amount" aqui é a quantidade de botões para se dividir a altura */}
                <SelectButton
                  amount={4}
                  onClick={() => setSelected(0)}
                  selected={selected === 0 ? true : false}
                >
                  <Typography variant="body2">Método CENDES/OPAS</Typography>
                </SelectButton>
                <SelectButton
                  amount={4}
                  onClick={() => setSelected(1)}
                  selected={selected === 1 ? true : false}
                >
                  <Typography variant="body2">
                    Enfoque estratégico
                  </Typography>
                </SelectButton>              
              </Box>
              <Box className="content">
                <Typography variant="body1">{texts[selected]}</Typography>
              </Box>
            </Box>
          </Box>
        </Content>
      </Box>
      <Footer prev="/p4" next="/p6" />
    </StyledContainer>
  )
}
