import React, { useState, useRef } from "react"
import { Typography, Box, useMediaQuery } from "@material-ui/core"

import Header from "../../components/Header"
import Footer from "../../components/Footer"
import Reference from "../../components/Reference"
import Accordion from "../../components/Accordion"

import { Content, StyledContainer } from "./styles"
import { TabButton } from "../../theme/commonstyles"

export default function () {
  const web = useMediaQuery("(min-width: 900px)")
  const headerref = useRef(Header)
  const [selected, setSelected] = useState(0)

  const openRef = (key) => {
    if (!headerref.current) {
      return
    }

    headerref.current.openRef(key)
  }

  const Explicativo = () => {
    return (
      <Typography variant="body1">
        Seleção e análise dos problemas relevantes para os atores sociais e
        sobre os quais se pretender intervir. <br />
        <br />
        • Seleção de problemas relevantes para os atores sociais e sobre os
        quais se pretender intervir; <br />
        • Priorização de problemas; <br />
        • Descrição dos problemas, por meio de indicadores ou descritores que o
        definam de modo explícito; <br />• Análise dos problemas e sua rede de
        causas.
      </Typography>
    )
  }

  const Normativo = () => {
    return (
      <Typography variant="body1">
        Construção do plano de intervenção, a situação objetiva que se deseja
        alcançar. <br />
        <br />• Descrição da nova situação a ser atingida a partir da
        transformação dos descritores do problema em descritores de resultados
        esperados; <br />• Definição das ações que serão realizadas.
      </Typography>
    )
  }

  const Estrategico = () => {
    return (
      <Typography variant="body1">
        Análise de viabilidade das ações e a construção de sua viabilidade
        quando consideradas essenciais. <br />
        <br />
        • Descrição dos recursos; <br />• Identificação dos atores que controlam
        os recursos.
      </Typography>
    )
  }

  const Tatico = () => {
    return (
      <Typography variant="body1">
        Implementação do plano. <br />
        <br />
        • Definição de ações e responsáveis; <br />
        • Definição de prazos; <br />• Monitoramento e avaliação do plano.
      </Typography>
    )
  }

  const texts = [<Explicativo />, <Normativo />, <Estrategico />, <Tatico />]
  const mobileTexts = [
    {
      title: "Explicativo",
      text: <Explicativo />,
    },
    {
      title: "Normativo",
      text: <Normativo />,
    },
    {
      title: "Estratégico",
      text: <Estrategico />,
    },
    {
      title: "Tático",
      text: <Tatico />,
    },
  ]

  return (
    <StyledContainer>
      <Header ref={headerref} />
      <Box className="container">
        <Content>
          <Box className="title">
            <Typography variant="h3">Enfoque estratégico</Typography>
          </Box>
          <Box className="wrapper">
            <Box className="text">
              <Typography variant="body1" className="indented">
                Do enfoque estratégico derivaram algumas vertentes, sendo o
                Planejamento Estratégico Situacional (PES) o mais difundido na
                organização das ações e dos serviços de saúde. Ele se divide em
                quatro momentos não sequenciais, concomitante e em permanente
                processo
                <Reference num={3} onClick={() => openRef(3)} />:
              </Typography>
            </Box>
            <Box className="middle">
              {web ? (
                <>
                  <Box className="buttons">
                    {/* "amount" aqui é a quantidade de botões para se dividir a altura */}
                    <TabButton
                      amount={4}
                      onClick={() => setSelected(0)}
                      selected={selected === 0}
                    >
                      <Typography variant="body2">Explicativo</Typography>
                    </TabButton>
                    <TabButton
                      amount={4}
                      onClick={() => setSelected(1)}
                      selected={selected === 1}
                    >
                      <Typography variant="body2">Normativo</Typography>
                    </TabButton>
                    <TabButton
                      amount={4}
                      onClick={() => setSelected(2)}
                      selected={selected === 2}
                    >
                      <Typography variant="body2">Estratégico</Typography>
                    </TabButton>
                    <TabButton
                      amount={4}
                      onClick={() => setSelected(3)}
                      selected={selected === 3}
                      last
                    >
                      <Typography variant="body2">
                        Tático-operacional
                      </Typography>
                    </TabButton>
                  </Box>
                  <Box className="content">
                    <Typography variant="body1">{texts[selected]}</Typography>
                  </Box>
                </>
              ) : (
                <Accordion texts={mobileTexts} />
              )}
            </Box>
            <Box className="text">
              <Typography variant="body1" className="indented">
                Essa perspectiva de estratégia de planejamento pode ser
                utilizada como suporte teórico-metodológico para orientar o
                processo de planejamento no SUS. Ao estar orientado para a
                compreensão da realidade em perspectiva ampliada, reconhecendo
                sua dinamicidade, e as visões dos diversos atores sobre ela, o
                enfoque estratégico se alinha à lógica de funcionamento do SUS.
              </Typography>
            </Box>
          </Box>
        </Content>
      </Box>
      <Footer prev="/p5" next="/p7" />
    </StyledContainer>
  )
}
