import styled, { css } from 'styled-components'

import opensans_bold from '../assets/fonts/OpenSans-Bold.ttf' 
import opensans_extrabold from '../assets/fonts/OpenSans-ExtraBold.ttf' 
import opensans_light from '../assets/fonts/OpenSans-Light.ttf' 
import opensans_regular from '../assets/fonts/OpenSans-Regular.ttf' 

export const containerstyles = css`
    background-color: ${props => props.theme.palette.background.main};
    display: flex;
    flex-direction: column;
    height: 100vh;    

    .container {
        max-width: 1920px;
        flex-grow: 1;
        display: flex;
        flex-direction: column;    
        overflow: auto;
        @media(min-width: 900px){
            max-width: 92.3%;
        };

        @media(min-width: 1200px) {
            overflow: hidden;
        }
    }
`

export const animationstyles = css`
    @keyframes fadeup {
        from {
            transform: translateY(20px);
            opacity: 0;
        }

        to {
            transform: translateY(0);
            opacity: 1;
        }
    }
`

export const fontstyles = css`
    @font-face {
        font-family: OpenSans;
        src: url(${opensans_bold});
        font-weight: bold;
        font-style: normal;
    }

    @font-face {
        font-family: OpenSans;
        src: url(${opensans_extrabold});
        font-weight: bolder;
        font-style: normal;
    }

    @font-face {
        font-family: OpenSans;
        src: url(${opensans_light});
        font-weight: lighter;
        font-style: normal;
    }

    @font-face {
        font-family: OpenSans;
        src: url(${opensans_regular});
        font-weight: normal;
        font-style: normal;
    }
`

export const contentstyles = css`
    padding: .5rem;

    @media(min-width: 900px) {
        padding: 1vh;
    }

    @media(min-width: 1800px) {
        padding: 4vh;
    }

    .text, .sidebox, .bottom, .objective, .imageandtext, .middle {
        @media(max-width: 900px) {
            display: block !important;
        }
    }

    .title {
        color: ${props => props.theme.palette.primary.main};

        h3 {
            margin: 0;
            margin-bottom: 1rem;
            font-family: opensans;
            font-weight: 900;

            @media(min-width: 900px) {
                margin-bottom: .5rem;
            }
        }
    }
`

export const SelectButton = styled.button`
    background-color: ${props => props.theme.palette.primary.main};
    color: ${props => props.theme.palette.background.main};
    display: flex;
    align-items: center;
    justify-content: center;
    text-align: center;
    padding: .4rem;
    margin: 0 .2rem;
    border-radius: 1rem;
    border: none;
    box-shadow: 0 1px 3px rgba(0,0,0,0.12), 0 1px 2px rgba(0,0,0,0.24);
    transition: 250ms ease;
    width: calc(50% - .4rem);
    height: 7rem;

    @media(min-width: 900px) {
      width: 100%;
      height: ${props => props.amount? `calc(100% / ${props.amount})`: "fit-content"};
      padding: .5rem;       
    }

    p {
        font-weight: 900;
    }

    &:focus {
        outline: none;
    }
    
    ${props => props.last? "" : "margin-bottom: .5rem"};
    ${props => props.selected? `
        background-color: ${props.theme.palette.primary.dark};        
        transform: scale(0.95);
    ` : ""};
`

export const TabButton = styled.button`
    background-color: ${props => props.theme.palette.primary.main};
    color: ${props => props.theme.palette.background.main};
    display: flex;
    align-items: center;
    justify-content: center;
    text-align: center;
    padding: .4rem;
    border-radius: 1rem 1rem 0 0;
    border: 4px solid ${props => props.theme.palette.primary.main};
    width: calc(50% - .4rem);
    height: 7rem;

    @media(min-width: 900px) {
      height: fit-content;
      width: 100%;
      padding: 1rem;
    }

    p {
        font-weight: 900;
    }

    &:focus {
        outline: none;
    }
    
    ${props => props.selected? `
        color: ${props.theme.palette.primary.main};
        background-color: ${props.theme.palette.background.main};
        border: 4px solid ${props.theme.palette.primary.main};
        position: relative;
        
        ::after {
          position: absolute;
          content: '';
          background: ${props.theme.palette.background.main};

          width: 100%;
          height: 8px;
          bottom: -8px;
        }
    ` : ""};

    ${props => props.last? "" : "margin-right: .5rem;"};
`